@@ -1,18 +1,18 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include <QMainWindow>
 #include <QGraphicsView>
 #include <QGeoServiceProvider>
 #include <QMenu>
 #include <QMenuBar>
 
+#include "customwindow.h"
 #include "locationprovider.h"
 #include "mapwidget.h"
 #include "cache.h"
-#include "gcprovider.h"
+#include "cacheprovider.h"
 
-class MainWindow : public QMainWindow {
+class MainWindow : public CustomWindow {
   Q_OBJECT;
 
  public:
@@ -21,14 +21,9 @@ class MainWindow : public QMainWindow {
 
  protected:
   void resizeEvent(QResizeEvent* event);
-  void keyPressEvent(QKeyEvent* event);
-  
- signals:
-  void increasePressed();
-  void decreasePressed();
   
  public slots:
-  void statusMessage(const QString &, int = 5000);
+  void statusMessage(const QString &);
   // called from map widget whenever the viewport changed
   void reloadCaches();
   // called from cacheprovider
@@ -36,17 +31,20 @@ class MainWindow : public QMainWindow {
   void displayError(const QString &);
   // called from map whenever the user clicked a cache icon
   void selectCache(const QString &);
-  
+  void detailCache(const QString &);
+  void setBusy(bool on);
+
  private slots:
   void about();
   void mapdialog();
-    
+  void showDetail(const Cache &);
+
  private:
-    void createMenu();
+  void createMenu();
     
   QGeoServiceProvider *m_serviceProvider;
   MapWidget *m_mapWidget;
-  GcProvider m_cacheProvider;
+  CacheProvider *m_cacheProvider;
   LocationProvider *m_locationProvider;
   QString m_message;   
   QGraphicsView *m_view;
