@@ -27,10 +27,12 @@ class MapWidget : public QGraphicsGeoMap {
   void updateZoomButtons();
   void hideBubble();
   QString managerName();
+  void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget * = 0);
 
  signals:
   void mapChanged();
   void cacheClicked(const QString &);
+  void detailClicked(const QString &);
   void showMessage(const QString &);
   
  public slots:
